@@ -343,6 +343,27 @@ class BaseController extends ActionController
      */
     public function listAction()
     {
+
+
+        //echo '<pre>',print_r($_POST),'</pre>';
+        $fromPost = [];
+        if(!empty($_POST)) {
+            if(isset($_POST['zip']) && !empty($_POST['zip']))
+                $fromPost['zip'] = trim(strip_tags($_POST['zip']));
+            if(isset($_POST['city']) && !empty($_POST['city']))
+                $fromPost['city'] = trim(strip_tags($_POST['city']));
+            if(isset($_POST['street']) && !empty($_POST['street']))
+                $fromPost['street'] = trim(strip_tags($_POST['street']));
+            if(isset($_POST['nr']) && !empty($_POST['nr']))
+                $fromPost['nr'] = trim(strip_tags($_POST['nr']));
+            if(isset($_POST['type']) && !empty($_POST['type']))
+                $fromPost['type'] = trim(strip_tags($_POST['type']));
+        }
+        $this->view->assign('fromPost', $fromPost);
+        //$this->view->assign('settings', $this->settings);
+
+
+        
             /**
              * @var $filter Filter
              */
@@ -426,14 +447,14 @@ class BaseController extends ActionController
                         // END: Assign Values for Slider-Configuration to View
                     }
                     $this->view->assign('realties', $realties);
+                    $citiesAndDistricts = $this->generateCityAndDistrictUniversal('array');
                     $this->view->assign('instantFilter', $this->generateInstantFilterPresetsFromResult($realties));
                     $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
-                    $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
-                    $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
+                    $this->view->assign('cityOptions', $this->getCitiesInRealty($citiesAndDistricts));
+                    $this->view->assign('groupedCitiesAndDistricts', $this->getStrangeFormatedCitiesAndDistricts($citiesAndDistricts));
                     $this->view->assign('filter', $this->filter);
                     $this->view->assign('aggregatedFilterData', json_encode($this->getAggregatedFilterData()));
                     $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
-
                     $this->view->assign('presets', $this->generateFilterPresetsFromResult($realties));
 
                     $entry = $this->view->render();
@@ -448,6 +469,35 @@ class BaseController extends ActionController
             }
     }
 
+    protected function getCitiesInRealty($cities) {
+        $returner = array();
+        foreach($cities as $city) {
+            $returner[$city['uid']] = $city['caption'];
+        }
+        return $returner;
+    }
+
+    protected function getStrangeFormatedCitiesAndDistricts($cities) {
+        $returner = array();
+        foreach($cities as $city) {
+            $returner[] = array($city['uid'] => $city['caption']);
+            if (is_array($city['districts']) && count($city['districts']) > 0) {
+                foreach ($city['districts'] as $district) {
+                    $returner[] = array($city['uid'] . '_' . $district['uid'] => $district['caption']);
+                }
+            }
+        }
+        return $returner;
+    }
+
+
+
+
+
+
+
+
+
     /**
      * @param string $realty Without any route enhancer the urlIdentifier (externalId) will be passed.
      *                       With route enhancer the uid of the estate item will be passed.
@@ -578,6 +628,157 @@ class BaseController extends ActionController
         return $this->generateCityAndDistrictUniversal('array');
     }
 
+    protected function image_resize($src, $dst, $resize_width, $resize_height) {
+        list($width, $height) = getimagesize($src);
+        $ratio = $width / $height;
+        if ($width > $height) {
+            $width = ceil($width-($width*abs($ratio - ($resize_width / $resize_height))));
+        } else {
+            $height = ceil($height-($height*abs($ratio - ($resize_width / $resize_height))));
+        }
+        $new_width = $resize_width;
+        $new_height = $resize_height;
+        $resized_image = imagecreatetruecolor($new_width, $new_height);
+        $info = pathinfo($src);
+        $type = $info['extension'];
+        switch ($type) {
+            case 'png':
+                $image = imagecreatefrompng($src);
+                imagecopyresampled($resized_image, $image, 0, 0, 0, 0, $new_width, $new_height, $width, $height);
+                imagepng($resized_image, $dst);
+                break;
+            case 'gif':
+                $image = imagecreatefromgif($src);
+                imagecopyresampled($resized_image, $image, 0, 0, 0, 0, $new_width, $new_height, $width, $height);
+                imagegif($resized_image, $dst);
+                break;
+            default:
+                $image = imagecreatefromjpeg($src);
+                imagecopyresampled($resized_image, $image, 0, 0, 0, 0, $new_width, $new_height, $width, $height);
+                imagejpeg($resized_image, $dst);
+        }
+        return 0;
+    }
+
+    public function getReactJson() {
+        $cw = '320';
+        $ch = '240';
+        $sql = "a.uid AS id,
+            a.objektnr_intern AS objectNumberInternal,
+            a.objektnr_extern AS objectNumberExternal,
+            a.openimmo_objid AS openimmoObjId,
+            a.objekttitel AS title,
+            a.objekt_strasse AS street,
+            a.objekt_hausnummer AS houseNumber,
+            a.objekt_plz AS zip,
+            a.wohnflaeche AS size,
+            a.anzahl_zimmer AS rooms,
+            a.nettokaltmiete AS rent,
+            IF(a.anzahl_balkone > 0, 'true', 'false') as balcony,
+            a.objekt_breitengrad AS lat,
+            a.objekt_laengengrad AS lng,
+            a.objekt_stadtteil AS district_id,
+            IFNULL(b.bezeichner, '') AS district_name,
+            c.kuerzel AS object_art,
+            a.objekt_ort AS city_id,
+            d.bezeichner AS city_name,
+            e.datei AS image,
+            '' as identifier, 
+            t.bezeichner AS object_arttyp 
+            FROM tx_sgestatecore_domain_model_immobilie AS a
+            LEFT JOIN tx_sgestatecore_domain_model_stadtteil AS b ON a.objekt_stadtteil = b.uid
+            LEFT JOIN tx_sgestatecore_domain_model_objektart AS c ON a.objektart = c.uid
+            LEFT JOIN tx_sgestatecore_domain_model_ort AS d ON a.objekt_ort = d.uid 
+            LEFT JOIN (SELECT immobilie, datei, typ FROM tx_sgestatecore_domain_model_anhang WHERE typ IN (1, 7) GROUP BY immobilie) 
+                AS e ON a.uid = e.immobilie 
+            LEFT JOIN tx_sgestatecore_domain_model_objektarttyp AS t ON a.objektarttyp = t.uid 
+            WHERE a.deleted = 0
+            AND a.hidden = 0;";
+        $connection = GeneralUtility::makeInstance(ConnectionPool::class)->getConnectionByName('Default');
+        $allRealties = $connection->createQueryBuilder()->addSelectLiteral($sql)->execute()->fetchAll();
+        $arrayReturn = ['realties' => []];
+        $_files = glob(Environment::getPublicPath() . '/fileadmin/React/Data/Previews/*');
+        foreach($_files as $_file)
+            if(is_file($_file))
+                @unlink($_file);
+        foreach ($allRealties as $realty) {
+            $src = Environment::getPublicPath() . '/uploads/tx_sgestatecore/media/' . $realty['image'];
+            $dst = Environment::getPublicPath() . '/fileadmin/React/Data/Previews/' . $realty['image'];
+            $imageUrl = '/fileadmin/React/Data/Previews/' . $realty['image'];
+            if (file_exists($src))
+                $this->image_resize($src, $dst, $cw, $ch);
+            $objectManager = GeneralUtility::makeInstance('TYPO3\\CMS\Extbase\\Object\\ObjectManager');
+            $configurationManager = $objectManager->get('TYPO3\\CMS\\Extbase\\Configuration\\ConfigurationManager');
+            $extbaseFrameworkConfiguration = $configurationManager->getConfiguration(ConfigurationManagerInterface::CONFIGURATION_TYPE_FULL_TYPOSCRIPT);
+            $detailPid = $extbaseFrameworkConfiguration['plugin.']['tx_sgestatebase.']['widgets.']['searchbox.']['settings.']['pid.']['detail'];
+            $itemUrl = $this->uriBuilder->reset()->setTargetPageUid($detailPid)->uriFor('detail', ['realty' => preg_replace(array('/\//','/\\\/'),'-',$realty['objectNumberExternal'])], 'Base', 'sgestatebase', 'pi1');
+            if(empty($itemUrl) || strpos($itemUrl, 'typo3') !== false)
+                $itemUrl = '/immobilien/detail/' . preg_replace(array('/\//','/\\\/'),'-',$realty['objectNumberExternal']);
+//            $is = rand(0, 1);
+//            $can = $is == 0 ? rand(0, 1) : 0;
+//            $lock = rand(0, 1);
+            $is = 0;
+            $can = 0;
+            $lock = 0;
+            array_push($arrayReturn['realties'], [
+                'show' => false,
+                'highlighted' => false,
+                'id' => $realty['id'],
+                'type' => $realty['object_art'],
+                'arttype' => $realty['object_arttyp'],
+                'data' => [
+                    'objectNumberInternal' => $realty['objectNumberInternal'],
+                    'objectNumberExternal' => $realty['objectNumberExternal'],
+                    'openimmoObjid' => $realty['openimmoObjId'],
+                    'title' => $realty['title'],
+                    'street' => $realty['street'],
+                    'nr' => $realty['houseNumber'],
+                    'zip' => $realty['zip'],
+                    'size' => $realty['size'],
+                    'rooms' => $realty['rooms'],
+                    'rent' => $realty['rent'],
+                    'balcony' => $realty['balcony'],
+                    'city' => [
+                        'id' => $realty['city_id'],
+                        'name' => $realty['city_name']
+                    ],
+                    'district' => [
+                        'id' => $realty['district_id'],
+                        'name' => $realty['district_name']
+                    ],
+                    'url' => $itemUrl
+                ],
+                'media' => [
+                    'preview' => $imageUrl
+                ],
+                'geometry' => [
+                    'location' => [
+                        'lat' => $realty['lat'],
+                        'lng' => $realty['lng']
+                    ]
+                ],
+                'parking' => [
+                    'wallbox' => [
+                        'is' => $is,
+                        'can' => $can
+                    ],
+                    'lock' => $lock
+                ],
+            ]);
+        }
+        return json_encode($arrayReturn);
+    }
+
+    protected function getDataForReact() {
+        // $file = dirname(__FILE__) . '../../Resources/Public/Data/react.json';
+        $file = Environment::getPublicPath() . '/fileadmin/React/Data/react.json';
+        if(file_exists($file) && filesize($file))
+            $json = file_get_contents($file);
+        else
+            $json = $this->getReactJson();
+        return json_encode(json_decode($json));
+    }
+
     /**
      * Action used for several AJAX Calls
      *
@@ -594,180 +795,12 @@ class BaseController extends ActionController
             $function = $this->request->getArgument('function');
             $this->view->assign('function', ucfirst($function));
             switch ($function) {
-
-//                case 'realtiesForReactApplication':
-//                    //$cacheIdentifier = 'ajax_realtiesForReactApplication';
-//                    //if (($entry = $this->cache->get($cacheIdentifier)) === false) {
-//                        $allRealties = $this->immobilieRepository->findAll();
-//                        $arrayReturn = [
-//                            'realties' => []
-//                        ];
-//                        $processingInstructions = [
-//                            'width' => '150c',
-//                            'height' => '112c',
-//                        ];
-//                        foreach ($allRealties as $realty) {
-//                            /**
-//                             * @var $realty Immobilie
-//                             */
-//                            $district = [];
-//                            if ($realty->getObjektStadtteil() instanceof Stadtteil) {
-//                                $district = [
-//                                    'id' => $realty->getObjektStadtteil()->getUid(),
-//                                    'name' => $realty->getObjektStadtteil()->getBezeichner()
-//                                ];
-//                            }
-//                            $image = $this->imageService->getImage(Environment::getPublicPath() . '/uploads/tx_sgestatecore/media/' . $realty->getTitelbild()->getDatei(), null, false);
-//                            $processedImage = $this->imageService->applyProcessingInstructions($image, $processingInstructions);
-//
-//                            array_push($arrayReturn['realties'], [
-//                                'show' => false,
-//                                'highlighted' => false,
-//                                'id' => $realty->getUid(),
-//                                'type' => $realty->getObjektart()->getKuerzel(),
-//                                'data' => [
-//                                    'objectNumberInternal' => $realty->getObjektnrIntern(),
-//                                    'objectNumberExternal' => $realty->getObjektnrExtern(),
-//                                    'openimmoObjid' => $realty->getOpenimmoObjid(),
-//                                    'title' => $realty->getObjekttitel(),
-//                                    'street' => $realty->getObjektStrasse(),
-//                                    'houseNumber' => $realty->getObjektHausnummer(),
-//                                    'zip' => $realty->getObjektPlz(),
-//                                    'size' => $realty->getWohnflaeche(),
-//                                    'rooms' => $realty->getAnzahlZimmer(),
-//                                    'rent' => $realty->getNettokaltmiete(),
-//                                    'balcony' => $realty->getAnzahlBalkone() > 0 ? true : false,
-//                                    'city' => [
-//                                        'id' => $realty->getObjektOrt()->getUid(),
-//                                        'name' => $realty->getObjektOrt()->getBezeichner()
-//                                    ],
-//                                    'district' => $district,
-//                                    'url' => $this->uriBuilder->reset()->setTargetPageUid($this->settings['pid']['detail'])->uriFor('detail', ['realty' => $realty->getUrlIdentifier()], 'Base', 'sgestatebase', 'pi1')
-//                                ],
-//                                'media' => [
-//                                    'preview' => $this->imageService->getImageUri($processedImage)
-//                                ],
-//                                'geometry' => [
-//                                    'location' => [
-//                                        'lat' => $realty->getObjektBreitengrad(),
-//                                        'lng' => $realty->getObjektLaengengrad()
-//                                    ]
-//                                ],
-//                            ]);
-//                        }
-//                        $this->view->assign('jsonReturn', json_encode($arrayReturn));
-//
-//                        $entry = $this->view->render();
-//
-//                        $tags = ['ajax_realtiesForReactApplication'];
-//                        //$lifetime = $this->settings['defaultCacheLifetime'];
-//
-//                        // Save value in cache
-//                        //$this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
-//                    //}
-//                    return $entry;
-//                    break;
-
-
                 case 'realtiesForReactApplication':
-                    $cw = '150';
-                    $ch = '112';
-                    $sql = "a.uid AS id, 
-                            a.objektnr_intern AS objectNumberInternal,
-                            a.objektnr_extern AS objectNumberExternal,
-                            a.openimmo_objid AS openimmoObjId,
-                            a.objekttitel AS title,
-                            a.objekt_strasse AS street,
-                            a.objekt_hausnummer AS houseNumber,
-                            a.objekt_plz AS zip, 
-                            a.wohnflaeche AS size, 
-                            a.anzahl_zimmer AS rooms,
-                            a.nettokaltmiete AS rent,
-                            IF(a.anzahl_balkone > 0, 'true', 'false') as balcony,
-                            a.objekt_breitengrad AS lat,
-                            a.objekt_laengengrad AS lng,
-                            a.objekt_stadtteil AS district_id,
-                            IFNULL(b.bezeichner, '') AS district_name,
-                            c.kuerzel AS object_art,
-                            a.objekt_ort AS city_id,
-                            d.bezeichner AS city_name,
-                            e.datei AS image, 
-                            f.identifier
-                        FROM tx_sgestatecore_domain_model_immobilie AS a
-                            LEFT JOIN tx_sgestatecore_domain_model_stadtteil AS b ON a.objekt_stadtteil = b.uid 
-                            LEFT JOIN tx_sgestatecore_domain_model_objektart AS c ON a.objektart = c.uid
-                            LEFT JOIN tx_sgestatecore_domain_model_ort AS d ON a.objekt_ort = d.uid 
-                            LEFT JOIN (
-                                SELECT immobilie, datei, typ 
-                                FROM tx_sgestatecore_domain_model_anhang 
-                                WHERE typ IN (1, 7) 
-                                GROUP BY immobilie 
-                                ORDER BY typ ASC, uid ASC
-                            ) AS e ON a.uid = e.immobilie  
-                            LEFT JOIN sys_file AS s ON s.name = e.datei
-                            LEFT JOIN sys_file_processedfile AS f ON 
-                                s.uid = f.original 
-                                AND task_type = 'Image.CropScaleMask' 
-                                AND width = " . $cw . "
-                                AND height = " .$ch. " 
-                        WHERE a.deleted = 0 
-                        AND a.hidden = 0;";
-
-                    $connection = GeneralUtility::makeInstance(ConnectionPool::class)->getConnectionByName('Default');
-                    $allRealties = $connection->createQueryBuilder()->addSelectLiteral($sql)->execute()->fetchAll();
-                    $arrayReturn = ['realties' => []];
-                    $processingInstructions = ['width' => $cw .'c', 'height' => $ch . 'c',];
-                    foreach ($allRealties as $realty) {
-                        if(!is_null($realty['identifier'])) {
-                            $imageUrl = $realty['identifier'];
-                        } else {
-                            $image = $this->imageService->getImage(Environment::getPublicPath() . '/uploads/tx_sgestatecore/media/' . $realty['image'], null, false);
-                            $imageUrl = $this->imageService->getImageUri($this->imageService->applyProcessingInstructions($image, $processingInstructions));
-                        }
-                        $itemUrl = $this->uriBuilder->reset()->setTargetPageUid($this->settings['pid']['detail'])->uriFor('detail', ['realty' => preg_replace(array('/\//','/\\\/'),'-',$realty['objectNumberExternal'])], 'Base', 'sgestatebase', 'pi1');
-                        array_push($arrayReturn['realties'], [
-                            'show' => false,
-                            'highlighted' => false,
-                            'id' => $realty['id'],
-                            'type' => $realty['object_art'],
-                            'data' => [
-                                'objectNumberInternal' => $realty['objectNumberInternal'],
-                                'objectNumberExternal' => $realty['objectNumberExternal'],
-                                'openimmoObjid' => $realty['openimmoObjId'],
-                                'title' => $realty['title'],
-                                'street' => $realty['street'],
-                                'houseNumber' => $realty['houseNumber'],
-                                'zip' => $realty['zip'],
-                                'size' => $realty['size'],
-                                'rooms' => $realty['rooms'],
-                                'rent' => $realty['rent'],
-                                'balcony' => $realty['balcony'],
-                                'city' => [
-                                    'id' => $realty['city_id'],
-                                    'name' => $realty['city_name']
-                                ],
-                                'district' => [
-                                    'id' => $realty['district_id'],
-                                    'name' => $realty['district_name']
-                                ],
-                                'url' => $itemUrl
-                            ],
-                            'media' => [
-                                'preview' => $imageUrl
-                            ],
-                            'geometry' => [
-                                'location' => [
-                                    'lat' => $realty['lat'],
-                                    'lng' => $realty['lng']
-                                ]
-                            ],
-                        ]);
-                    }
-                    $this->view->assign('jsonReturn', json_encode($arrayReturn));
+                    $json = $this->getDataForReact();
+                    $this->view->assign('jsonReturn', $json);
                     $entry = $this->view->render();
                     return $entry;
-                    break;
-
+                break;
                 case 'allRealties':
                     $cacheIdentifier = 'ajax_allRealties';
 
